@@ -7,7 +7,7 @@
 #   * Provides a unified validation API
 #
 
-require 'tk'
+require 'tk' unless defined?(Tk)
 require 'tkextlib/tcllib.rb'
 
 # TkPackage.require('widget::validator', '0.1')
