@@ -3,7 +3,7 @@
 #  tcombobox widget
 #                               by Hidetoshi NAGAI (nagai@ai.kyutech.ac.jp)
 #
-require 'tk'
+require 'tk' unless defined?(Tk)
 require 'tkextlib/tile.rb'
 
 module Tk
